@@ -1,4 +1,4 @@
-from cameo_claw import it_distinct, it_download, it_group
+from cameo_claw import it_distinct, it_download, it_group, it_filter
 import time
 from cameo_claw.log import log
 
@@ -106,17 +106,35 @@ def test_it_group():
         print(f'done url: {done_url}')
 
 
+def test_it_filter():
+    target_directory = './data/topic_filter/'
+    int_total = len(get_lst_url())
+    lst_distinct_column = ['deviceId', 'localTime', 'sensorId']
+    lst_column_match = [['sensorId', 'pm2_5'], ['sensorId', 'voc']]
+    sort_column = 'localTime'
+    for int_progress, done_url in it_filter(
+            get_lst_url(), target_directory, lst_distinct_column,
+            lst_column_match, sort_column):
+        print(f'int_progress/int_total = {int_progress}/{int_total}')
+        print(f'done url: {done_url}')
+
+
 if __name__ == '__main__':
     # t = time.time()
     # test_it_download()
     # log(f'test_it_download:{time.time() - t}')
     #
+
     # t = time.time()
     # test_it_distinct()
     # log(f'test_it_distinct:{time.time() - t}')
 
+    # t = time.time()
+    # test_it_group()
+    # log(f'test_it_group:{time.time() - t}')
+
     t = time.time()
-    test_it_group()
-    log(f'test_it_group:{time.time() - t}')
+    test_it_filter()
+    log(f'test_it_filter:{time.time() - t}')
 
 # sh/go.sh
